@@ -2,11 +2,10 @@
 This hopes to recreate the functionality of the ACRG repo function
 footprints_data_merge
 """
-from typing import Any, Dict, Optional, Tuple, Union, cast
-
-from openghg.dataobjects import FootprintData, ObsData
 from pandas import Timestamp
-from xarray import DataArray, Dataset
+from xarray import Dataset, DataArray
+from typing import Optional, Tuple, Union, Dict, Any
+from openghg.dataobjects import FootprintData
 
 # from openghg.dataobjects import FluxData
 
@@ -48,7 +47,7 @@ def single_site_footprint(
     Returns:
         xarray.Dataset
     """
-    from openghg.retrieve import get_footprint, get_obs_surface
+    from openghg.retrieve import get_obs_surface, get_footprint
     from openghg.util import timestamp_tzaware
 
     start_date = timestamp_tzaware(start_date)
@@ -74,7 +73,6 @@ def single_site_footprint(
         species=species,
         instrument=instrument,
     )
-    obs_results = cast(ObsData, obs_results)
 
     obs_data = obs_results.data
 
@@ -244,7 +242,15 @@ def footprints_data_merge(
     if calc_timeseries:
         combined_dataset = add_timeseries(combined_dataset=combined_dataset, flux_dict=flux_dict)
 
-    return FootprintData(data=combined_dataset, metadata={})
+    return FootprintData(
+        data=combined_dataset,
+        metadata={},
+        flux=flux_dict,
+        bc={},
+        species=species,
+        scales="scale",
+        units="units",
+    )
 
 
 def combine_datasets(
@@ -555,12 +561,11 @@ def timeseries_HiTRes(
      TODO: mypy having trouble with different types options and incompatible types,
      included as Any for now.
     """
-    from math import gcd
-
-    import dask.array as da  # type: ignore
     import numpy as np
-    from pandas import date_range
+    import dask.array as da  # type: ignore
     from tqdm import tqdm
+    from pandas import date_range
+    from math import gcd
 
     fp_HiTRes = combined_dataset.fp_HiTRes
 
