@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Dict
 
 from ._basedata import _BaseData
 
@@ -19,5 +20,15 @@ class FootprintData(_BaseData):
         units: Measurements units
     """
 
+    flux: Dict
+    bc: Dict
+    species: str
+    scales: str
+    units: str
+
     def __str__(self) -> str:
-        return f"Data: {self.data}\nMetadata : {self.metadata}"
+        return (
+            f"Data: {self.data}\nMetadata : {self.metadata}"
+            f"\nFlux : {self.flux}\nBC: {self.bc}"
+            f"\nSpecies : {self.species}\nScales: {self.scales}\nUnits: {self.units}"
+        )
