@@ -1,12 +1,7 @@
 from pathlib import Path
-from typing import Any, Dict, Hashable, Optional, Union, cast
-import logging
-import xarray as xr
-
-from openghg.types import optionalPathType
-
-logger = logging.getLogger("openghg.standardise.surface")
-logger.setLevel(logging.DEBUG)  # Have to set level for logger as well as handler
+from typing import Dict, Optional, Union
+from xarray import Dataset
+import numpy as np
 
 
 def parse_noaa(
@@ -17,28 +12,17 @@ def parse_noaa(
     network: str = "NOAA",
     instrument: Optional[str] = None,
     sampling_period: Optional[str] = None,
-    update_mismatch: str = "never",
-    site_filepath: optionalPathType = None,
-    **kwarg: Dict,
 ) -> Dict:
     """Read NOAA data from raw text file or ObsPack NetCDF
 
     Args:
         data_filepath: Data filepath
         site: Three letter site code
-        inlet: Inlet height (as value unit e.g. "10m")
+        inlet: Inlet height, if no height use measurement type e.g. flask
         measurement_type: One of ("flask", "insitu", "pfp")
         network: Network, defaults to NOAA
         instrument: Instrument name
         sampling_period: Sampling period
-        update_mismatch: This determines how mismatches between the internal data
-            attributes and the supplied / derived metadata are handled.
-            This includes the options:
-                - "never" - don't update mismatches and raise an AttrMismatchError
-                - "attributes" - update mismatches based on input attributes
-                - "metadata" - update mismatches based on input metadata
-        site_filepath: Alternative site info file (see openghg/supplementary_data repository for format).
-            Otherwise will use the data stored within openghg_defs/data/site_info JSON file by default.
     Returns:
         dict: Dictionary of data and metadata
     """
@@ -57,8 +41,6 @@ def parse_noaa(
             measurement_type=measurement_type,
             instrument=instrument,
             sampling_period=sampling_period,
-            update_mismatch=update_mismatch,
-            site_filepath=site_filepath,
         )
     else:
         return _read_raw_file(
@@ -68,12 +50,51 @@ def parse_noaa(
             measurement_type=measurement_type,
             instrument=instrument,
             sampling_period=sampling_period,
-            update_mismatch=update_mismatch,
-            site_filepath=site_filepath,
         )
 
 
-def _standarise_variables(obspack_ds: xr.Dataset, species: str) -> xr.Dataset:
+def _format_inlet(inlet: Union[str, float, int]) -> str:
+    """
+    Output inlet name in expected format. This will include 1 decimal place for floats with a fractional component
+    and 0 decimal places otherwise.
+
+    Args:
+        inlet : Inlet value. This can be a string as long as this can be converted directly to a float
+
+    Returns:
+        str : Formatted string of inlet name
+
+    Examples:
+        >>> _format_inlet(40)
+        "40m"
+        >>> _format_inlet("10.0")
+        "10m"
+        >>> _format_inlet(2.511432)
+        "2.5m"
+    """
+    if isinstance(inlet, str):
+        try:
+            inlet_value = float(inlet)
+        except ValueError:
+            inlet_values_str = inlet.split("-")
+            try:
+                inlet_values = [float(value) for value in inlet_values_str]
+            except ValueError:
+                raise ValueError("Unable to convert inlet {inlet} to a float")
+            else:
+                inlet_value = np.mean(inlet_values)
+    else:
+        inlet_value = inlet
+
+    if inlet_value % 1 == 0:
+        inlet_str = f"{inlet_value:.0f}m"
+    else:
+        inlet_str = f"{inlet_value:.1f}m"
+
+    return inlet_str
+
+
+def _standarise_variables(obspack_ds: Dataset, species: str) -> Dataset:
     """
     Converts data from NOAA ObsPack dataset into our standardised variables to be stored within the object store.
     The species is also needed so this name can be used to label the variables in the new dataset.
@@ -152,9 +173,7 @@ def _standarise_variables(obspack_ds: xr.Dataset, species: str) -> xr.Dataset:
     return processed_ds
 
 
-def _split_inlets(
-    obspack_ds: xr.Dataset, attributes: Dict, metadata: Dict, inlet: Optional[str] = None
-) -> Dict:
+def _split_inlets(obspack_ds: Dataset, attributes: Dict, metadata: Dict, inlet: Optional[str] = None) -> Dict:
     """
     Splits the overall dataset by different inlet values, if present. The expected dataset input should be from the NOAA ObsPack.
 
@@ -172,7 +191,6 @@ def _split_inlets(
         {"ch4_40m": {"data": xr.Dataset(...), "attributes": {...}, "metadata": {...}}, "ch4_60m": {...}, ...}
 
     """
-    from openghg.util import format_inlet
 
     orig_attrs = obspack_ds.attrs
     species = attributes["species"]
@@ -186,10 +204,11 @@ def _split_inlets(
 
     gas_data: Dict[str, Dict] = {}
     if height_var in obspack_ds.data_vars:
+
         if inlet is not None:
             # TODO: Add to logging?
-            logger.warning(
-                f"Ignoring inlet value of {inlet} since file has each data point has an associated height (contains 'intake_height' variable)"
+            print(
+                f"WARNING: Ignoring inlet value of {inlet} since file has each data point has an associated height (contains 'intake_height' variable)"
             )
 
         # Group dataset by the height values
@@ -199,9 +218,10 @@ def _split_inlets(
 
         # For each group standardise and store with id based on species and inlet height
         for ht, obspack_ds_ht in obspack_ds_grouped:
+
             # Creating id keys of the form "<species>_<inlet>" e.g. "ch4_40m" or "co_12.5m"
-            inlet_str = format_inlet(str(ht), key_name="inlet")
-            inlet_magl_str = format_inlet(str(ht), key_name="inlet_height_magl")
+            inlet_str = _format_inlet(ht)
+            inlet_num_str = inlet_str.strip("m")
 
             if num_groups > 1:
                 id_key = f"{species}_{inlet_str}"
@@ -219,9 +239,9 @@ def _split_inlets(
             meta_copy = metadata.copy()
 
             attrs_copy["inlet"] = inlet_str
-            attrs_copy["inlet_height_magl"] = inlet_magl_str
+            attrs_copy["inlet_height_magl"] = inlet_num_str
             meta_copy["inlet"] = inlet_str
-            meta_copy["inlet_height_magl"] = inlet_magl_str
+            meta_copy["inlet_height_magl"] = inlet_num_str
 
             gas_data[id_key]["metadata"] = meta_copy
             gas_data[id_key]["attributes"] = attrs_copy
@@ -232,7 +252,7 @@ def _split_inlets(
         except KeyError:
             inlet_from_file = None
         else:
-            inlet_from_file = format_inlet(str(inlet_value))
+            inlet_from_file = _format_inlet(inlet_value)
 
         if measurement_type == "flask":
             inlet_from_file = "flask"
@@ -242,8 +262,8 @@ def _split_inlets(
             inlet = inlet_from_file
         elif inlet is not None and inlet_from_file:
             if inlet != inlet_from_file:
-                logger.warning(
-                    f"Provided inlet {inlet} does not match inlet derived from the input file: {inlet_from_file}"
+                print(
+                    f"WARNING: Provided inlet {inlet} does not match inlet derived from the input file: {inlet_from_file}"
                 )
         else:
             raise ValueError(
@@ -253,14 +273,14 @@ def _split_inlets(
         id_key = f"{species}"
 
         if inlet != "flask":
-            inlet_magl_str = format_inlet(inlet, key_name="inlet_height_magl")
+            inlet_num_str = inlet.strip("m")
         else:
-            inlet_magl_str = "NA"
+            inlet_num_str = ""
 
         metadata["inlet"] = inlet
-        metadata["inlet_height_magl"] = inlet_magl_str
+        metadata["inlet_height_magl"] = inlet_num_str
         attributes["inlet"] = inlet
-        attributes["inlet_height_magl"] = inlet_magl_str
+        attributes["inlet_height_magl"] = inlet_num_str
 
         standardised_ds = _standarise_variables(obspack_ds, species)
 
@@ -276,8 +296,6 @@ def _read_obspack(
     measurement_type: str,
     inlet: Optional[str] = None,
     instrument: Optional[str] = None,
-    update_mismatch: str = "never",
-    site_filepath: optionalPathType = None,
 ) -> Dict[str, Dict]:
     """Read NOAA ObsPack NetCDF files
 
@@ -288,28 +306,21 @@ def _read_obspack(
         measurement_type: One of flask, insitu or pfp
         inlet: Inlet height, if no height use measurement type e.g. flask
         instrument: Instrument name
-        update_mismatch: This determines how mismatches between the internal data
-            "attributes" and the supplied / derived "metadata" are handled.
-            This includes the options:
-              - "never" - don't update mismatches and raise an AttrMismatchError
-              - "from_source" / "attributes" - update mismatches based on input data (e.g. data attributes)
-              - "from_definition" / "metadata" - update mismatches based on associated data (e.g. site_info.json)
-        site_filepath: Alternative site info file (see openghg/supplementary_data repository for format).
-            Otherwise will use the data stored within openghg_defs/data/site_info JSON file by default.
+
     Returns:
         dict: Dictionary of results
     """
-    from openghg.standardise.meta import assign_attributes
+    import xarray as xr
     from openghg.util import clean_string
+    from openghg.standardise.meta import assign_attributes
 
     valid_types = ("flask", "insitu", "pfp")
 
     if measurement_type not in valid_types:
         raise ValueError(f"measurement_type must be one of {valid_types}")
 
-    with xr.open_dataset(data_filepath) as temp:
-        obspack_ds = temp
-        orig_attrs = temp.attrs
+    obspack_ds = xr.open_dataset(data_filepath)
+    orig_attrs = obspack_ds.attrs
 
     # Want to find and drop any duplicate time values for the original dataset
     # Using xarray directly we have to do in a slightly convoluted way as this is not well built
@@ -350,8 +361,21 @@ def _read_obspack(
         # Extract units attribute from value data variable
         units = processed_ds["value"].units
     except (KeyError, AttributeError):
-        logger.warning("Unable to extract units from 'value' within input dataset")
-        units = "NA"
+        print("Unable to extract units from 'value' within input dataset")
+    else:
+        if units == "mol mol-1":
+            units = "1"
+        elif units == "millimol mol-1":
+            units = "1e-3"
+        elif units == "micromol mol-1":
+            units = "1e-6"
+        elif units in ["nmol mol-1", "nanomol mol-1"]:
+            units = "1e-9"
+        elif units == "pmol mol-1":
+            units = "1e-12"
+        else:
+            print(f"Using unit {units} directly")
+            # raise ValueError(f"Did not recognise input units from file: {units}")
 
     metadata = {}
     metadata["site"] = site
@@ -360,8 +384,6 @@ def _read_obspack(
     metadata["species"] = species
     metadata["units"] = units
     metadata["sampling_period"] = sampling_period
-    metadata["data_source"] = "noaa_obspack"
-    metadata["data_type"] = "surface"
 
     # Add additional sampling_period_estimate if sampling_period is not set
     if sampling_period_estimate >= 0.0:
@@ -383,7 +405,7 @@ def _read_obspack(
     metadata["calibration_scale"] = orig_attrs.get("dataset_calibration_scale", "NOT_SET")
 
     # Create attributes with copy of metadata values
-    attributes = cast(Dict[Hashable, Any], metadata.copy())  # Cast to match xarray attributes type
+    attributes = metadata.copy()
 
     # TODO: At the moment all attributes from the NOAA ObsPack are being copied
     # plus any variables we're adding - decide if we want to reduce this
@@ -402,13 +424,7 @@ def _read_obspack(
 
     gas_data = _split_inlets(processed_ds, attributes, metadata, inlet=inlet)
 
-    gas_data = assign_attributes(
-        data=gas_data,
-        site=site,
-        network=network,
-        update_mismatch=update_mismatch,
-        site_filepath=site_filepath,
-    )
+    gas_data = assign_attributes(data=gas_data, site=site, network=network)
 
     return gas_data
 
@@ -420,8 +436,6 @@ def _read_raw_file(
     measurement_type: str,
     inlet: Optional[str] = None,
     instrument: Optional[str] = None,
-    update_mismatch: str = "never",
-    site_filepath: optionalPathType = None,
 ) -> Dict:
     """Reads NOAA data files and returns a dictionary of processed
     data and metadata.
@@ -433,14 +447,6 @@ def _read_raw_file(
         measurement_type: One of flask, insitu or pfp
         inlet: Inlet height, if no height use measurement type e.g. flask
         instrument: Instrument name
-        update_mismatch: This determines how mismatches between the internal data
-            "attributes" and the supplied / derived "metadata" are handled.
-            This includes the options:
-              - "never" - don't update mismatches and raise an AttrMismatchError
-              - "from_source" / "attributes" - update mismatches based on input data (e.g. data attributes)
-              - "from_definition" / "metadata" - update mismatches based on associated data (e.g. site_info.json)
-        site_filepath: Alternative site info file (see openghg/supplementary_data repository for format).
-            Otherwise will use the data stored within openghg_defs/data/site_info JSON file by default.
 
     Returns:
         list: UUIDs of Datasources data has been assigned to
@@ -468,9 +474,7 @@ def _read_raw_file(
         sampling_period=sampling_period,
     )
 
-    gas_data = assign_attributes(
-        data=gas_data, site=site, network="NOAA", update_mismatch=update_mismatch, site_filepath=site_filepath
-    )
+    gas_data = assign_attributes(data=gas_data, site=site, network="NOAA")
 
     return gas_data
 
@@ -494,8 +498,8 @@ def _read_raw_data(
     Returns:
         dict: Dictionary containing attributes, data and metadata keys
     """
-    from openghg.util import clean_string, read_header, get_site_info, load_internal_json
-    from pandas import Timestamp, read_csv
+    from openghg.util import clean_string, read_header, load_json
+    from pandas import read_csv, Timestamp
 
     header = read_header(filepath=data_filepath)
 
@@ -549,7 +553,7 @@ def _read_raw_data(
     # Read the site code from the Dataframe
     site = str(data["sample_site_code"][0]).upper()
 
-    site_data = get_site_info()
+    site_data = load_json("acrg_site_info.json")
     # If this isn't a site we recognize try and read it from the filename
     if site not in site_data:
         site = str(data_filepath.name).split("_")[1].upper()
@@ -605,7 +609,7 @@ def _read_raw_data(
     data = data.to_xarray()
 
     # TODO  - this could do with a better name
-    noaa_params = load_internal_json(filename="attributes.json")["NOAA"]
+    noaa_params = load_json("attributes.json")["NOAA"]
 
     site_attributes = noaa_params["global_attributes"]
     site_attributes["inlet_height_magl"] = "NA"
@@ -620,8 +624,6 @@ def _read_raw_data(
     metadata["inlet"] = inlet
     metadata["sampling_period"] = sampling_period
     metadata["instrument"] = noaa_params["instrument"][species.upper()]
-    metadata["data_type"] = "surface"
-    metadata["source_format"] = "noaa"
 
     combined_data[species.lower()] = {
         "metadata": metadata,
@@ -632,7 +634,7 @@ def _read_raw_data(
     return combined_data
 
 
-def _estimate_sampling_period(obspack_ds: xr.Dataset, min_estimate: float = 10.0) -> float:
+def _estimate_sampling_period(obspack_ds: Dataset, min_estimate: float = 10.0) -> float:
     """
     Estimate the sampling period for the NOAA data using either the "data_selection_tag"
     attribute (this sometimes contains useful information such as "HourlyData") or by using
